summaryrefslogtreecommitdiffstats
path: root/kio
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-06 00:38:29 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-06 00:38:29 -0600
commitca1f1a08ecb01139487ff2f0591f97b97164c4e4 (patch)
tree3d890700d69458192fddd1829688a8a4e10a0c65 /kio
parentd4e11a5f488204ab8886e167c7c4af1e6e16ab58 (diff)
downloadtdelibs-ca1f1a08ecb01139487ff2f0591f97b97164c4e4.tar.gz
tdelibs-ca1f1a08ecb01139487ff2f0591f97b97164c4e4.zip
Rename tqencodedData to fix bindings
Diffstat (limited to 'kio')
-rw-r--r--kio/bookmarks/kbookmarkdrag.cc12
-rw-r--r--kio/bookmarks/kbookmarkdrag.h2
-rw-r--r--kio/kio/paste.cpp6
3 files changed, 10 insertions, 10 deletions
diff --git a/kio/bookmarks/kbookmarkdrag.h b/kio/bookmarks/kbookmarkdrag.h
index c67f1ea19..c213f2d93 100644
--- a/kio/bookmarks/kbookmarkdrag.h
+++ b/kio/bookmarks/kbookmarkdrag.h
@@ -43,7 +43,7 @@ public:
virtual ~KBookmarkDrag() {}
virtual const char* format( int i ) const;
- virtual TQByteArray tqencodedData( const char* mime ) const;
+ virtual TQByteArray encodedData( const char* mime ) const;
static bool canDecode( const TQMimeSource * e );
static TQValueList<KBookmark> decode( const TQMimeSource * e );
diff --git a/kio/kio/paste.cpp b/kio/kio/paste.cpp
index 5a74c3e48..99714ffa7 100644
--- a/kio/kio/paste.cpp
+++ b/kio/kio/paste.cpp
@@ -137,7 +137,7 @@ static KIO::CopyJob* chooseAndPaste( const KURL& u, TQMimeSource* data,
if ( clipboard ) {
data = TQApplication::tqclipboard()->data();
}
- const TQByteArray ba = data->tqencodedData( chosenFormat );
+ const TQByteArray ba = data->encodedData( chosenFormat );
return pasteDataAsyncTo( new_url, ba );
}
#endif
@@ -147,7 +147,7 @@ KIO_EXPORT bool KIO::isClipboardEmpty()
{
#ifndef QT_NO_MIMECLIPBOARD
TQMimeSource *data = TQApplication::tqclipboard()->data();
- if ( data->provides( "text/uri-list" ) && data->tqencodedData( "text/uri-list" ).size() > 0 )
+ if ( data->provides( "text/uri-list" ) && data->encodedData( "text/uri-list" ).size() > 0 )
return false;
#else
// Happens with some versions of Qt Embedded... :/
@@ -194,7 +194,7 @@ KIO::CopyJob* KIO::pasteMimeSource( TQMimeSource* data, const KURL& dest_url,
if ( formats.size() > 1 ) {
return chooseAndPaste( dest_url, data, formats, dialogText, widget, clipboard );
}
- ba = data->tqencodedData( formats.first() );
+ ba = data->encodedData( formats.first() );
}
if ( ba.size() == 0 )
{
diff --git a/kio/bookmarks/kbookmarkdrag.cc b/kio/bookmarks/kbookmarkdrag.cc
index 358e329a9..d13893eed 100644
--- a/kio/bookmarks/kbookmarkdrag.cc
+++ b/kio/bookmarks/kbookmarkdrag.cc
@@ -54,8 +54,8 @@ KBookmarkDrag::KBookmarkDrag( const TQValueList<KBookmark> & bookmarks, const TQ
: TQUriDrag( urls, dragSource, name ), m_bookmarks( bookmarks ), m_doc("xbel")
{
// We need to create the XML for this drag right now and not
// in tqencodedData because when cutting a folder, the children
// wouldn't be part of the bookmarks anymore, when tqencodedData
// is requested.
TQDomElement elem = m_doc.createElement("xbel");
m_doc.appendChild( elem );
@@ -76,16 +76,16 @@ const char* KBookmarkDrag::format( int i ) const
else return 0;
}
-TQByteArray KBookmarkDrag::tqencodedData( const char* mime ) const
+TQByteArray KBookmarkDrag::encodedData( const char* mime ) const
{
TQByteArray a;
TQCString mimetype( mime );
if ( mimetype == "text/uri-list" )
- return TQUriDrag::tqencodedData( mime );
+ return TQUriDrag::encodedData( mime );
else if ( mimetype == "application/x-xbel" )
{
a = m_doc.toCString();
- //kdDebug(7043) << "KBookmarkDrag::tqencodedData " << m_doc.toCString() << endl;
+ //kdDebug(7043) << "KBookmarkDrag::encodedData " << m_doc.toCString() << endl;
}
else if ( mimetype == "text/plain" )
{
@@ -117,7 +117,7 @@ TQValueList<KBookmark> KBookmarkDrag::decode( const TQMimeSource * e )
TQValueList<KBookmark> bookmarks;
if ( e->provides("application/x-xbel") )
{
- TQByteArray s( e->tqencodedData("application/x-xbel") );
+ TQByteArray s( e->encodedData("application/x-xbel") );
//kdDebug(7043) << "KBookmarkDrag::decode s=" << TQCString(s) << endl;
TQDomDocument doc;
doc.setContent( s );
@@ -54,8 +54,8 @@ KBookmarkDrag::KBookmarkDrag( const TQValueList<KBookmark> & bookmarks, const TQ
{
// We need to create the XML for this drag right now and not
- // in tqencodedData because when cutting a folder, the children
- // wouldn't be part of the bookmarks anymore, when tqencodedData
+ // in encodedData because when cutting a folder, the children
+ // wouldn't be part of the bookmarks anymore, when encodedData
// is requested.
TQDomElement elem = m_doc.createElement("xbel");